"gAlgo""gAlgo" is a "VIRTUAL" class, the common basis of classes
"pcAlgo" and "fciAlgo".We describe the common slots here; for more see the help pages of the specific classes.
call:call object: the original function call.n:"integer", the sample size used to estimate the graph.max.ord:integer, the maximum size of
the conditioning set used in the conditional independence tests of
the (first part of the algorithm), in function skeleton.n.edgetests:sepset:list, the conditioning sets
that led to edge deletions. The set that led to the removal of
the edge i -- j is saved in either sepset[[i]][[j]] or
in sepset[[j]][[i]].pMax:matrix, where the
$(i,j)$th entry contains the maximal p-value of all conditional
independence tests for edge $i -- j$."pcAlgo" and "fciAlgo".