showAmat: Show Adjacency Matrix of pcAlgo object
Description
Show the adjacency matrix of a "pcAlgo" object; this is
intended to be an alternative if the Rgraphviz package does not work.
Arguments
object
an R object of class pcAlgo, as returned
from skeleton() or pc(). Value
The adjacency matrix.
See Also
showEdgeList for showing the edge list of a pcAlgo object.
iplotPC for plotting a "pcAlgo" object using the package
igraph also for an example of showAmat().