as(*, "amat") instead ! Show the adjacency matrix of a "pcAlgo" object; this is
intended to be an alternative if the Rgraphviz package does not work.
showAmat(object)showEdgeList for showing the edge list of a pcAlgo object.
iplotPC for plotting a "pcAlgo" object using the package
igraph also for an example of showAmat().